@@ -15,6 +15,17 @@ from .chinesecardbin import CARDBIN_LIST
 from .dbhelper import exec_sql
 
 
+prov_dict = {
+    '11':'北京市','12':'天津市','13':'河北省','14':'山西省','15':'内蒙古自治区',
+    '21':'辽宁省','22':'吉林省','23':'黑龙江省',
+    '31':'上海市','32':'江苏省','33':'浙江省','34':'安徽省','35':'福建省','36':'江西省','37':'山东省',
+    '41':'河南省','42':'湖北省','43':'湖南省',
+    '44':'广东省','45':'广西壮族自治区','46':'海南省',
+    '50':'重庆市','51':'四川省','52':'贵州省','53':'云南省','54':'西藏自治区',
+    '61':'陕西省','62':'甘肃省','63':'青海省','64':'宁夏回族自治区','65':'新疆维吾尔族自治区',
+    '81':'香港特别行政区','82':'澳门特别行政区','83':'台湾地区'
+}
+
 class PersonalInfo:
     """
     个人信息
@@ -86,13 +97,15 @@ class PersonalInfo:
             }
             return bd[b]
 
-    def create_idcard(self):
+    def create_idcard(self, min_age=18, max_age=50, city_code_list=None) -> str:
         """
         身份证
         """
         cur = datetime.now()
-        id = str(random.choice(CITYCODE_LIST))  #地区码
-        id = id + str(random.randint(cur.year-100, cur.year-18))  #年份项
+        if not city_code_list:
+            city_code_list = CITYCODE_LIST
+        id = str(random.choice(city_code_list))  #地区码
+        id = id + str(random.randint(cur.year-max_age, cur.year-min_age))  #年份项
         da = date.today() + timedelta(days=random.randint(1, 366))  #月份和日期项
         id = id + da.strftime('%m%d')
         id = id + str(random.randint(100, 300))  #顺序号简单处理
@@ -117,7 +130,6 @@ class PersonalInfo:
             "Phone": self.create_phone()
         }
 
-
 class DateTimeUtil:
     """
     封装一些常用的日期/时间
@@ -197,11 +209,29 @@ class DateTimeUtil:
         '''
         return str(date.today().day)
 
+    def get_between_dates(self, begin_date, end_date, fmt="%Y-%m-%d") -> list:
+        '''
+        获取指定日期范围的每天：
+        fmt：时间格式
+        '''
+        date_list = []
+        begin_date = datetime.strptime(begin_date, fmt)
+        end_date = datetime.strptime(end_date, fmt)
+        while begin_date <= end_date:
+            date_str = begin_date.strftime(fmt)
+            date_list.append(date_str)
+            begin_date += timedelta(days=1)
+        return date_list
 
-import json
-import requests
-from lazy_testdata.dbhelper import exec_sql
-
+    def utc_gmt8(self, utf_time, fmt="%Y-%m-%d %H:%M:%S"):
+        targe_time = utf_time
+        try:
+            _date = datetime.strptime(utf_time,"%Y-%m-%dT%H:%M:%S.%fZ")
+            _date = _date + timedelta(hours=8)
+            targe_time = _date.strftime(fmt)
+        except Exception as err:
+            print(err)
+        return targe_time
 
 class Swagger2Case():
 
@@ -341,16 +371,20 @@ class Swagger2Case():
                         except Exception as err:
                             print(f"出异常了，相关变量：tmp['items']={tmp['items']},详细信息：{err}")
             else:
-                if 'array' in x["type"]:
-                    try:
-                        para_dict[name] = [type_value.setdefault(
-                        x["items"]["type"], x["items"]["type"])]
-                    except Exception as err:
-                        print("出错了～")
-                        print(x["type"])
-                else:
-                    para_dict[name] = type_value.setdefault(
-                        x["type"], x["type"])
+                try:
+                    if 'array' in x["type"]:
+                        try:
+                            para_dict[name] = [type_value.setdefault(
+                            x["items"]["type"], x["items"]["type"])]
+                        except Exception as err:
+                            print("出错了～")
+                            print(x["type"])
+                    else:
+                        para_dict[name] = type_value.setdefault(
+                            x["type"], x["type"])
+                except Exception as err:
+                    print(f"出错了～{err}")
+                    print(x)
 
         try:
             result = json.dumps(para_dict)
@@ -501,19 +535,67 @@ class Swagger2Case():
         # exec_sql(conn,node_sql)
         # exec_sql(conn,node_flow_sql)   
 
+class IDTool(object):
+    def __init__(self,id_card):
+        self.id_card = str(id_card)
+    
+    def get_birth_prov(self):
+        code = self.id_card[0:2]
+        return prov_dict[code]
+
+    def get_gender(self):#性别
+        sex=self.id_card[-2]#倒数第二位
+        sex=int(sex)
+        if sex/2:
+            print('男')
+            return 1
+        else:
+            print('女')
+            return 0
+
+    def get_age(self):
+        birthday = self.id_card[6:14]#出生年月日
+        birth_year=birthday[0:4]#前四位
+        age= datetime.now().year-int(birth_year)#int换算
+        print(str(age)+'岁')
+        return age
+
+    def get_birthday(self):
+        birthday = self.id_card[6:14]#出生年月日
+        print(birthday)
+        year = birthday[0:4]#前四位
+        month = birthday[4:6]
+        date = birthday[-2:]
+        return f"{year}-{month}-{date}"
+
+    def id_flag(self):#辨别真假
+        key_flag=[7,9,10,5,8,4,2,1,6,3,7,9,10,5,8,4,2]#17位相乘系数数组
+        flag_lastnumber=[1,0,'X',9,8,7,6,5,4,3,2]#%11对应的余数得到的校验码，下标为余数
+        last = self.id_card[-1]#最后一位
+        arry_number=list(map(int,self.id_card))#map转化数组
+        arry_number.pop()#删除最后一个校验位
+        tuple_flag=list(zip(key_flag,arry_number))#合成元组
+        sum=0#记录相乘之后的和
+        for p in tuple_flag:
+            #得出一组数
+            each=1#系数为1与他们相乘
+            for q in p:
+                each=q*each
+            sum+=each#记录每组数的乘积和
+        result=sum%11#对11取余数
+        calculate=flag_lastnumber[result]
+        if calculate==int(last):
+            print('身份证正确')
+        else:
+            print('身份证错误')
+            return 0
+        return 1
+
+
 if __name__ == '__main__':
     # TMP = PersonalInfo()
     # su = DateTimeUtil()
     # print(su.get_sql_dt(6))
     # print(TMP.fourelements())
     # print(TMP.full_name())
-    env_name = 'scfp-test-v1'
-    conn = 'mysql+pymysql://root:pwd@localhost:3306/common_api_test'
-    url = 'http://10.228.64.54:24009/'
-    json_file = 'swagger2case-gauge/resource/swagger.json'
-    sc = Swagger2Case(env_name, conn, domain_url=url)
-    # sc = Swagger2Case(env_name, conn, swagger_json_file=json_file)
-    sc.combine_all_args_case()
-    sc.combine_none_args_case()
-    sc.get_first_resp()
-    sc.insert_db()
+    print(1)
\ No newline at end of file
